<?php

namespace LaminasTest\Code\Reflection\TestAsset;

/** Short Class Description */
class TestSampleClass13
{
    /** Short Method Description */
    public function doSomething()
    {}

    /** @return Something This describes something */
    public function returnSomething()
    {}
}
